SplashScreen class

Inheritance

Constructors

SplashScreen(String name, WidgetBuilder? next, {String? loopAnimation, Key? key, bool? isLoading, Color? backgroundColor, Future<void> until()?, Alignment alignment = Alignment.center, double? width, double? height, RouteTransitionsBuilder? transitionsBuilder, String? endAnimation, String? startAnimation, dynamic onSuccess(dynamic data)?, dynamic onError(dynamic error, dynamic stacktrace)?, BoxFit? fit})
const
SplashScreen.callback({required String name, required dynamic onSuccess(dynamic data), required dynamic onError(dynamic error, dynamic stacktrace), Key? key, Future until()?, bool? isLoading, BoxFit fit = BoxFit.contain, Color? backgroundColor, String? loopAnimation, Alignment alignment = Alignment.center, double? width, double? height, String? endAnimation, RouteTransitionsBuilder? transitionsBuilder, String? startAnimation})
factory
SplashScreen.navigate({required String name, required WidgetBuilder next, Key? key, bool? isLoading, Color? backgroundColor, Future until()?, String? loopAnimation, Alignment alignment = Alignment.center, BoxFit fit = BoxFit.contain, double? width, double? height, String? endAnimation, RouteTransitionsBuilder? transitionsBuilder, String? startAnimation})
factory

Properties

alignment → Alignment
final
backgroundColor → Color?
final
endAnimation → String?
final
fit → BoxFit?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
isLoading → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loopAnimation → String?
final
name → String
final
next → WidgetBuilder?
final
onError → dynamic Function(dynamic error, dynamic stacktrace)?
final
onSuccess → dynamic Function(dynamic data)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAnimation → String?
final
transitionsBuilder → RouteTransitionsBuilder?
final
until → Future<void> Function()?
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited